/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.example.jetsnack.ui.home

import android.content.res.Configuration
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.*
import androidx.compose.material.SnackbarDefaults.backgroundColor
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Favorite
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.RectangleShape
import androidx.compose.ui.layout.VerticalAlignmentLine
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.example.jetsnack.R
import com.example.jetsnack.ui.components.JetsnackDivider
import com.example.jetsnack.ui.theme.JetsnackTheme
import com.example.jetsnack.ui.theme.Shadow4
import com.example.jetsnack.ui.theme.Shadow5

@Composable
fun Profile(modifier: Modifier = Modifier, navController: NavHostController) {
    Column(
        /*horizontalAlignment = Alignment.CenterHorizontally,*/
        modifier = modifier
            .fillMaxSize()
            .padding(24.dp)
            .height(760.dp)
        /*.wrapContentSize()
        .padding(24.dp)*/
    ) {
        Spacer(Modifier.height(48.dp))
        Row(
            /*modifier = modifier
                .fillMaxSize()
                .wrapContentSize()
                .padding(24.dp)*/
        ) {
            Text(
                text = "圖",

                style = MaterialTheme.typography.subtitle1,
                textAlign = TextAlign.Left,
            )
            Spacer(Modifier.width(24.dp))
            Text(
                text = "Anderson",
                style = MaterialTheme.typography.subtitle1,
            )
            Spacer(Modifier.width(200.dp))
            Box(
                modifier = Modifier.height(24.dp)
            ) {
                Image(
                    painterResource(R.drawable.setting),
                    contentDescription = null,
                    modifier = Modifier.fillMaxSize().clickable { navController.navigate("Setting")}
                )
            }
        }
        Spacer(Modifier.height(16.dp))
        Box(
            modifier = Modifier.height(400.dp).clickable { navController.navigate("SelectDog") }
        ) {
            Image(
                painterResource(R.drawable.dog),
                contentDescription = null,
                modifier = Modifier.fillMaxSize()
            )
        }
        Spacer(Modifier.height(8.dp))
        Row(
            modifier = Modifier.fillMaxWidth(),
            horizontalArrangement = Arrangement.SpaceEvenly
        ) {
            Column(
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                Text(text = "專注計時器", fontSize = 20.sp)
                Text(text = "05:00",fontSize = 24.sp)

            }
            Column(
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                Text(text = "休息計時器",fontSize = 20.sp)
                Text(text = "02:00",fontSize = 24.sp)
            }
        }
        Spacer(Modifier.height(56.dp))
        Row(
            modifier = Modifier.fillMaxWidth(),
            horizontalArrangement = Arrangement.SpaceEvenly,
            verticalAlignment = Alignment.CenterVertically
        ) {
            Column(
                horizontalAlignment = Alignment.CenterHorizontally,
                /*verticalArrangement = Arrangement.Center,*/
                modifier = Modifier
                    .width(70.dp)
                    .clickable { }
            ) {
                Image(
                    painterResource(R.drawable.breed),
                    contentDescription = null,
                )
                Text(text = "孵蛋", color = Color.DarkGray)
            }
            Button(
                onClick = { navController.navigate("focusProcess")},
                contentPadding = PaddingValues(
                    start = 40.dp,
                    top = 20.dp,
                    end = 40.dp,
                    bottom = 20.dp
                ),
                colors = ButtonDefaults.buttonColors(backgroundColor = Shadow4 ),
            ) {
                Text("開始", color = Color.White)
            }
            Column(
                horizontalAlignment = Alignment.CenterHorizontally,
                verticalArrangement = Arrangement.Center,
                modifier = Modifier
                    .width(70.dp)
                    .clickable { }
            ) {
                Image(
                    painterResource(R.drawable.focus),
                    contentDescription = null,
                )
                Text(text = "多人專注", color = Color.DarkGray)
            }
        }
    }
}
