/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.example.jetsnack.ui.home

import android.content.res.Configuration
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.itemsIndexed
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.key
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.jetsnack.R
import com.example.jetsnack.model.Egg
import com.example.jetsnack.model.Eggs
import com.example.jetsnack.model.SnackCollection
import com.example.jetsnack.model.SnackRepo
import com.example.jetsnack.ui.components.*
import com.example.jetsnack.ui.theme.JetsnackTheme
import com.example.jetsnack.ui.theme.Lavender3
import com.example.jetsnack.ui.theme.Lavender4

@Composable
fun Shop(
    modifier: Modifier = Modifier
) {
    val eggscollection = Eggs
    Shop(
        eggscollection,
        modifier
    )
}

@Composable
private fun Shop(eggscollection: List<Egg>, modifier: Modifier = Modifier) {

    LazyColumn {
        item {
            Spacer(
                Modifier.windowInsetsTopHeight(
                    WindowInsets.statusBars.add(WindowInsets(top = 80.dp))
                )
            )
        }
        items(4) { data ->
            Spacer(Modifier.height(16.dp))
            Row(
                horizontalArrangement = Arrangement.Center,
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier.fillMaxWidth()
            ) {
                Column(
                    horizontalAlignment = Alignment.CenterHorizontally,
                    modifier = Modifier
                        .clip(RoundedCornerShape(20.dp))
                        .background(Color(eggscollection[data * 2].color))
                        .width(180.dp)
                        .clickable {/*todo*/ }
                ) {
                    Spacer(Modifier.height(20.dp))
                    Box(
                        modifier = Modifier
                            .height(100.dp)
                            .width(100.dp)
                    ) {
                        Image(
                            painter = painterResource(eggscollection[data * 2].picture),
                            modifier = modifier.fillMaxSize(),
                            contentDescription = null
                        )

                    }
                    Spacer(Modifier.height(16.dp))
                    Text(
                        fontSize = 22.sp,
                        text = eggscollection[data * 2].name + "專注蛋",
                        style = MaterialTheme.typography.h6,
                        textAlign = TextAlign.Center,
                        modifier = Modifier.fillMaxWidth()
                    )
                    Row(
                        horizontalArrangement = Arrangement.Center,
                        verticalAlignment = Alignment.CenterVertically,
                        modifier = modifier.fillMaxWidth()
                    ) {
                        Image(
                            painterResource(R.drawable.coin),
                            contentDescription = null,
                            modifier = modifier.size(20.dp)
                        )
                        Spacer(
                            Modifier.width(10.dp)
                        )
                        Text(
                            fontSize = 20.sp,
                            text = "${eggscollection[data * 2].price}",
                            style = MaterialTheme.typography.body2,
                            textAlign = TextAlign.Center,
                        )
                        Spacer(
                            Modifier.width(10.dp)
                        )

                    }
                    Spacer(Modifier.height(10.dp))
                }
                Spacer(Modifier.width(20.dp))
                Column(
                    horizontalAlignment = Alignment.CenterHorizontally,
                    modifier = Modifier
                        .clip(RoundedCornerShape(20.dp))
                        .background(Color(eggscollection[data * 2 + 1].color))
                        .width(180.dp)
                        .clickable {/*todo*/ }

                ) {
                    Spacer(Modifier.height(20.dp))
                    Box(
                        modifier = Modifier
                            .height(100.dp)
                            .width(100.dp)
                    ) {
                        Image(
                            painter = painterResource(eggscollection[data * 2 + 1].picture),
                            modifier = modifier.fillMaxSize(),
                            contentDescription = null
                        )

                    }
                    Spacer(Modifier.height(16.dp))
                    Text(
                        fontSize = 22.sp,
                        text = eggscollection[data * 2 + 1].name + "專注蛋",
                        style = MaterialTheme.typography.h6,
                        textAlign = TextAlign.Center,
                        modifier = Modifier.fillMaxWidth()
                    )
                    Row(
                        horizontalArrangement = Arrangement.Center,
                        verticalAlignment = Alignment.CenterVertically,
                        modifier = modifier.fillMaxWidth()
                    ) {
                        Image(
                            painterResource(R.drawable.coin),
                            contentDescription = null,
                            modifier = modifier.size(20.dp)
                        )
                        Spacer(
                            Modifier.width(10.dp)
                        )
                        Text(
                            fontSize = 20.sp,
                            text = "${eggscollection[data * 2 + 1].price}",
                            style = MaterialTheme.typography.body2,
                            textAlign = TextAlign.Center,
                        )
                        Spacer(
                            Modifier.width(10.dp)
                        )

                    }
                    Spacer(Modifier.height(10.dp))
                }
            }
        }

        item { Spacer(Modifier.height(16.dp)) }
    }
    Column(
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = Modifier.background(Color(0xffffffff))
    ) {
        Spacer(
            Modifier.windowInsetsTopHeight(
                WindowInsets.statusBars.add(WindowInsets(top = 28.dp))
            )
        )
        Row(
            horizontalArrangement = Arrangement.SpaceBetween,
            verticalAlignment = Alignment.CenterVertically,
            modifier = modifier.fillMaxWidth()
        ) {
            Row(modifier = modifier.width(70.dp)) {

            }
            Text(
                text = "商店",
                style = MaterialTheme.typography.subtitle1,
                textAlign = TextAlign.Center,
                fontSize = 24.sp,
            )
            Row(
                horizontalArrangement = Arrangement.Start,
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier.width(70.dp)
            ) {
                Text(
                    text = "1500",
                    style = MaterialTheme.typography.h3,
                    textAlign = TextAlign.Center,
                    fontSize = 16.sp,

                    )
                Spacer(
                    Modifier.width(5.dp)
                )
                Image(
                    painterResource(R.drawable.coin),
                    contentDescription = null,
                    modifier = modifier.size(20.dp)
                )
            }
        }
        Spacer(Modifier.height(20.dp))
    }

}

@Preview("default")
@Preview("dark theme", uiMode = Configuration.UI_MODE_NIGHT_YES)
@Preview("large font", fontScale = 2f)
@Composable
fun EggsPreview() {
    JetsnackTheme {
        Shop()
    }
}
